/**
  *  \file flak/pdk-platform.cc
  *  \brief Implementation of Platform (arch) methods for a PDK-based program
  *
  *  We cannot really mix our platform support and PDK in a program. 
  *  Whereas the PDK uses the libc character set throughout, our
  *  platform uses UTF-8.
  *
  *  Because most parts do not even care about the character set, this
  *  implements the platform support using the libc character set. It
  *  implements only the parts which are actually needed by FLAK.
  *
  *  Stream::openFile is taken from arch/generic/file.cc, which uses a
  *  C++ fstream.
  *
  *  (c) 2001-2015 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "arch/platform.h"
#include "io/dirs.h"

/* Platform */

const char Platform::LINE_SEPARATOR[] = "\n";
const char Platform::PATH_SEPARATOR;

string_t
Platform::getResourceDirectory()
{
    /* Like most host-addons, we expect our additional files in the
       current directory. */
    return ".";
}

string_t
Platform::getLanguageCode()
{
    /* Regular messages are not translated; for other messages, the
       FLAK host uses its own (per-player) configuration mechanism. */
    return "en";
}

void
Platform::showOutput()
{ }

/* Directory and Stream */

string_t
Directory::makeFileName(string_t a, string_t b)
{
    /* The PDK uses "/" or "\", depending on the operating system. 
       Because Windows supports both, we just use "/". */
    return a + "/" + b;
}
