/**
  *  \file game/exp.cc
  *  \brief Experience Handling
  *
  *  (c) 2001-2015 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/exp.h"
#include "game/config.h"
#include "game/host.h"
#include "util/nls.h"
#include "cpluslib/format.h"


/** Format experience level set into string. This is intended to
    format level restrictions, hence it returns an empty string if the
    set contains all levels. Otherwise, returns a human-readable list
    of the experience levels in \c set. */
string_t
formatExpLevelSet(GExpLevelSet set)
{
    GExpLevelSet allLevels = host.isPHost() ? GExpLevelSet::allUpTo(config.NumExperienceLevels()) : GExpLevelSet(0);
    set &= allLevels;

    if (set == allLevels) {
        // all levels
        return string_t();
    }
    if (set.empty()) {
        // no levels
        return _("no level");
    }
    if (set.isUnitSet()) {
        // one level
        for (int i = 0; i <= NUM_EXPERIENCE_LEVELS; ++i)
            if (set.contains(i))
                return format(_("level %d"), i);
    }

    // Find minimum level
    int minLevel = 0;
    while (!set.contains(minLevel))
        ++minLevel;

    if (minLevel != 0 && set + GExpLevelSet::allUpTo(minLevel-1) == allLevels) {
        // all levels from X onwards
        return format(_("level %d+"), minLevel);
    }

    // mixed
    string_t result;
    const char* prefix = _("levels ");
    for (int i = 1; i <= NUM_PLAYERS; ++i) {
        if (set.contains(i)) {
            result += prefix;
            result += format("%d", i);
            prefix = ", ";
        }
    }
    return result;
}
